==> v1.3.3.zip: joomla-sermon-distributor/README.md <==
# Sermon Distributor (1.3.3)

 ![Sermon Distributor image] (https://raw.githubusercontent.com/SermonDistributor/Joomla-3-Component/master/admin/assets/images/component-300.jpg "The Sermon Distributor")

Distributor is a highly advanced sermon distributor that runs on the [Joomla 3.x] (http://www.joomla.org) framework. You can link a shared folder from Dropbox to the component and use Dropbox as your file host, not to mention the advanced auto builder that gives you the ability to simply load sermons to your website by only adding them to Dropbox.

The best way to see all your options is to install this component on you Joomla website and test all features yourself. Here is a [direct download link] (https://github.com/SermonDistributor/Joomla-3-Component/archive/master.zip)

 **If you like our component please rate it on the [Joomla Index] (http://extensions.joomla.org/extensions/extension/living/religion/sermon-distributor)**

### Example Website, That Has Over 6000 Audio Files

[LoudVoice.org] (http://www.loudvoice.org)

### Some Video Demonstrations

+ [Setup overview] (https://youtu.be/yMPp1Cp3W_0?t=20m8s)
+ [Setup Dropbox] (https://youtu.be/btpKFDk0-dI)

# Build Details

+ *Company*: [Vast Development Method] (https://www.vdm.io/)
+ *Author*: [Llewellyn van der Merwe] (mailto:llewellyn@vdm.io)
+ *Name*: [Sermon Distributor] (https://www.vdm.io/)
+ *First Build*: 22nd October, 2015
+ *Last Build*: 2nd July, 2016
+ *Version*: 1.3.3
+ *Copyright*: Copyright (C) 2015. All Rights Reserved
+ *License*: GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html

## Build Time :hourglass:

**137 Hours** or **17 Eight Hour Days** (actual time the author saved -
due to [Automated Component Builder] (https://www.vdm.io/joomla-component-builder))

> (if creating a folder and file took **5 seconds** and writing one line of code took **10 seconds**,
> never making one mistake or taking any coffee break.)

+ *Line count*: **49061**
+ *File count*: **355**
+ *Folder count*: **80**

**90 Hours** or **11 Eight Hour Days** (the actual time the author spent)

> (with the following break down:
> **debugging @34hours** = codingtime / 4;
> **planning @20hours** = codingtime / 7;
> **mapping @14hours** = codingtime / 10;
> **office @23hours** = codingtime / 6;)

**227 Hours** or **28 Eight Hour Days**
(a total of the realistic time frame for this project)

> (if creating a folder and file took **5 seconds** and writing one line of code took **10 seconds**,
> with the normal everyday realities at the office, that includes the component planning, mapping & debugging.)

Project duration: **5.6 weeks** or **1.2 months**

> This **component** was build with a Joomla [Automated Component Builder] (https://www.vdm.io/joomla-component-builder).
> Developed by [Llewellyn van der Merwe] (mailto:joomla@vdm.io)

==> v1.3.4.zip: joomla-sermon-distributor/README.md <==
# Sermon Distributor (1.3.4)

 ![Sermon Distributor image] (https://raw.githubusercontent.com/SermonDistributor/Joomla-3-Component/master/admin/assets/images/component-300.jpg "The Sermon Distributor")

Distributor is a highly advanced sermon distributor that runs on the [Joomla 3.x] (http://www.joomla.org) framework. You can link a shared folder from Dropbox to the component and use Dropbox as your file host, not to mention the advanced auto builder that gives you the ability to simply load sermons to your website by only adding them to Dropbox.

The best way to see all your options is to install this component on you Joomla website and test all features yourself. Here is a [direct download link] (https://github.com/SermonDistributor/Joomla-3-Component/archive/master.zip)

 **If you like our component please rate it on the [Joomla Index] (http://extensions.joomla.org/extensions/extension/living/religion/sermon-distributor)**

### Example Website, That Has Over 6000 Audio Files

[LoudVoice.org] (http://www.loudvoice.org)

### Some Video Demonstrations

+ [Setup overview] (https://youtu.be/yMPp1Cp3W_0?t=20m8s)
+ [Setup Dropbox] (https://youtu.be/btpKFDk0-dI)

# Build Details

+ *Company*: [Vast Development Method] (https://www.vdm.io/)
+ *Author*: [Llewellyn van der Merwe] (mailto:llewellyn@vdm.io)
+ *Name*: [Sermon Distributor] (https://www.vdm.io/)
+ *First Build*: 22nd October, 2015
+ *Last Build*: 16th July, 2016
+ *Version*: 1.3.4
+ *Copyright*: Copyright (C) 2015. All Rights Reserved
+ *License*: GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html

## Build Time :hourglass:

**137 Hours** or **17 Eight Hour Days** (actual time the author saved -
due to [Automated Component Builder] (https://www.vdm.io/joomla-component-builder))

> (if creating a folder and file took **5 seconds** and writing one line of code took **10 seconds**,
> never making one mistake or taking any coffee break.)

+ *Line count*: **49071**
+ *File count*: **356**
+ *Folder count*: **80**

**90 Hours** or **11 Eight Hour Days** (the actual time the author spent)

> (with the following break down:
> **debugging @34hours** = codingtime / 4;
> **planning @20hours** = codingtime / 7;
> **mapping @14hours** = codingtime / 10;
> **office @23hours** = codingtime / 6;)

**227 Hours** or **28 Eight Hour Days**
(a total of the realistic time frame for this project)

> (if creating a folder and file took **5 seconds** and writing one line of code took **10 seconds**,
> with the normal everyday realities at the office, that includes the component planning, mapping & debugging.)

Project duration: **5.6 weeks** or **1.2 months**

> This **component** was build with a Joomla [Automated Component Builder] (https://www.vdm.io/joomla-component-builder).
> Developed by [Llewellyn van der Merwe] (mailto:joomla@vdm.io)

## Donations

 If you want to support this project, please consider donating:
 * PayPal: pay@vdm.io
 * Bitcoin: 3H35PYwikEosvcjxHXGPLS1GufZ4b4iFu3
